@@ -8,6 +8,10 @@ import (
 	"{{GOLANG_MODULE}}/internal/query"
 )
 
+func init() {
+	AddRouteRegistrar(GetAppDescription)
+}
+
 func GetAppDescription(router *gin.RouterGroup) {
 	router.GET("/app/description", func(c *gin.Context) {
 		SendJSON(c, query.GetAppDescription())
