@@ -8,6 +8,10 @@ import (
 	"{{GOLANG_MODULE}}/internal/query"
 )
 
+func init() {
+	AddRouteRegistrar(GetAppDescription)
+}
+
 func GetAppDescription(router iris.Party) {
 	router.Get("/app/description", func(c iris.Context) {
 		SendJSON(c, query.GetAppDescription())
