@@ -4,7 +4,9 @@ package {{GOLANG_PACKAGE}}
 
 import (
 	"github.com/gin-gonic/gin"
-	"immigration-office-platform/internal/api"
+
+    "{{GOLANG_MODULE}}/internal/api"
+    "{{GOLANG_MODULE}}/internal/service"
 )
 
 func init() {
@@ -12,7 +14,8 @@ func init() {
 }
 
 func WebsocketServer(router *gin.RouterGroup) {
-	hub := newHub()
+	hub := newHub("example")
+	hub.broadcast = service.RealTimeMessageBroadcast
 	go hub.run()
 
 	router.GET("/ws", func(c *gin.Context) {
@@ -22,7 +25,7 @@ func WebsocketServer(router *gin.RouterGroup) {
 			return
 		}
 
-		client := NewClient(hubServer, conn, nil)
+		client := NewClient(hub, conn, nil, nil)
 		client.hub.register <- client
 
 		// Allow collection of memory referenced by the caller by doing all work in new goroutines.
